==> journeymap-api-fabric-2.0.0-1.21.5-20250403.130820-6-sources.jar: journeymap/api/v2/client/fullscreen/CustomToolBarBuilder.java <==
package journeymap.api.v2.client.fullscreen;

import net.minecraft.class_2960;
import org.jetbrains.annotations.NotNull;

public interface CustomToolBarBuilder
{
    /**
     * Creates and gets a theme toggle button with a separate on/off label.
     *
     * @param labelOn  - The on label, can be the display string or i18n key.
     * @param labelOff - The off label, can be the display string or i18n key.
     * @param icon - The icon name. Icon resourceLocation
     * @param onPress  - The onpress action.
     * @return IThemeButton
     */
    IThemeButton getThemeToggleButton(@NotNull String labelOn, @NotNull String labelOff, @NotNull class_2960 icon, @NotNull IThemeButton.Action onPress);

    /**
     * Creates and gets a theme button with a separate on/off label.
     *
     * @param labelOn  - The on label, can be the display string or i18n key.
     * @param labelOff - The off label, can be the display string or i18n key.
     * @param icon - The icon name. Icon resourceLocation
     * @param onPress  - The onpress action.
     * @return IThemeButton
     */
    IThemeButton getThemeButton(@NotNull String labelOn, @NotNull String labelOff, @NotNull class_2960 icon, @NotNull IThemeButton.Action onPress);

    /**
     * Creates and gets a theme toggle button with a separate on/off label.
     *
     * @param label    - The label, can be the display string or i18n key.
     * @param icon - The icon name. Icon resourceLocation
     * @param onPress  - The onpress action.
     * @return IThemeButton
     */
    IThemeButton getThemeToggleButton(@NotNull String label, @NotNull class_2960 icon, @NotNull IThemeButton.Action onPress);

    /**
     * Creates and gets a theme button with a separate on/off label.
     *
     * @param label    - The label, can be the display string or i18n key.
     * @param icon - The icon name. Icon resourceLocation
     * @param onPress  - The onpress action.
     * @return IThemeButton
     */
    IThemeButton getThemeButton(@NotNull String label, @NotNull class_2960 icon, @NotNull IThemeButton.Action onPress);


    /**
     * Gets a new toolbar instance.
     * All the buttons must be added here.
     *
     * @param themeButtons - The theme buttons.
     * @return The toolbar instance.
     */
    IThemeToolBar getNewToolbar(IThemeButton... themeButtons);
}

==> journeymap-api-fabric-2.0.0-1.21.11-20260206.193701-12-sources.jar: journeymap/api/v2/client/fullscreen/CustomToolBarBuilder.java <==
package journeymap.api.v2.client.fullscreen;

import net.minecraft.class_2960;
import org.jetbrains.annotations.NotNull;

public interface CustomToolBarBuilder
{
    /**
     * Creates and gets a theme toggle button with a separate on/off label.
     *
     * @param labelOn  - The on label, can be the display string or i18n key.
     * @param labelOff - The off label, can be the display string or i18n key.
     * @param icon - The icon name. Icon Identifier
     * @param onPress  - The onpress action.
     * @return IThemeButton
     */
    IThemeButton getThemeToggleButton(@NotNull String labelOn, @NotNull String labelOff, @NotNull class_2960 icon, @NotNull IThemeButton.Action onPress);

    /**
     * Creates and gets a theme button with a separate on/off label.
     *
     * @param labelOn  - The on label, can be the display string or i18n key.
     * @param labelOff - The off label, can be the display string or i18n key.
     * @param icon - The icon name. Icon Identifier
     * @param onPress  - The onpress action.
     * @return IThemeButton
     */
    IThemeButton getThemeButton(@NotNull String labelOn, @NotNull String labelOff, @NotNull class_2960 icon, @NotNull IThemeButton.Action onPress);

    /**
     * Creates and gets a theme toggle button with a separate on/off label.
     *
     * @param label    - The label, can be the display string or i18n key.
     * @param icon - The icon name. Icon Identifier
     * @param onPress  - The onpress action.
     * @return IThemeButton
     */
    IThemeButton getThemeToggleButton(@NotNull String label, @NotNull class_2960 icon, @NotNull IThemeButton.Action onPress);

    /**
     * Creates and gets a theme button with a separate on/off label.
     *
     * @param label    - The label, can be the display string or i18n key.
     * @param icon - The icon name. Icon Identifier
     * @param onPress  - The onpress action.
     * @return IThemeButton
     */
    IThemeButton getThemeButton(@NotNull String label, @NotNull class_2960 icon, @NotNull IThemeButton.Action onPress);


    /**
     * Gets a new toolbar instance.
     * All the buttons must be added here.
     *
     * @param themeButtons - The theme buttons.
     * @return The toolbar instance.
     */
    IThemeToolBar getNewToolbar(IThemeButton... themeButtons);
}
